Getting started
===============

Available Commands
-------------------

* djecrety

Supported Python versions
-------------------------

* Python 3.5
* Python 3.6

Supported Django versions
-------------------------

* Django 2.0
* Django 2.1
* Django 2.2

Installation
------------

.. code-block:: bash

    $ pip install djecrety

Configuration
-------------

Configure ``INSTALLED_APPS``:

.. code-block:: python

    INSTALLED_APPS = (
        ...
        'djecrety',
        ...
    )
